==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/bank_branches_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankBranchesController < CoreModelsController
    # GET /people_and_companies/bank_branches
    # GET /people_and_companies/bank_branches.json
    def index
      @people_and_companies_bank_branches = PeopleAndCompanies::BankBranch.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_branches }
      end
    end

    # GET /people_and_companies/bank_branches/1
    # GET /people_and_companies/bank_branches/1.json
    def show
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_branch }
      end
    end

    # GET /people_and_companies/bank_branches/new
    # GET /people_and_companies/bank_branches/new.json
    def new
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_branch }
      end
    end

    # GET /people_and_companies/bank_branches/1/edit
    def edit
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])
    end

    # POST /people_and_companies/bank_branches
    # POST /people_and_companies/bank_branches.json
    def create
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.new(params[:people_and_companies_bank_branch])

      respond_to do |format|
        if @people_and_companies_bank_branch.save
          format.html { redirect_to @people_and_companies_bank_branch, :notice => 'Bank branch was successfully created.' }
          format.json { render :json => @people_and_companies_bank_branch, :status => :created, :location => @people_and_companies_bank_branch }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_branch.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_branches/1
    # PUT /people_and_companies/bank_branches/1.json
    def update
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_branch.update_attributes(params[:people_and_companies_bank_branch])
          format.html { redirect_to @people_and_companies_bank_branch, :notice => 'Bank branch was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_branch.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_branches/1
    # DELETE /people_and_companies/bank_branches/1.json
    def destroy
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])
      @people_and_companies_bank_branch.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_branches_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/bank_branches_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankBranchesController < CoreModelsController
    # GET /people_and_companies/bank_branches
    # GET /people_and_companies/bank_branches.json
    def index
      @people_and_companies_bank_branches = PeopleAndCompanies::BankBranch.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_branches }
      end
    end

    # GET /people_and_companies/bank_branches/1
    # GET /people_and_companies/bank_branches/1.json
    def show
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_branch }
      end
    end

    # GET /people_and_companies/bank_branches/new
    # GET /people_and_companies/bank_branches/new.json
    def new
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_branch }
      end
    end

    # GET /people_and_companies/bank_branches/1/edit
    def edit
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])
    end

    # POST /people_and_companies/bank_branches
    # POST /people_and_companies/bank_branches.json
    def create
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.new(params[:people_and_companies_bank_branch])

      respond_to do |format|
        if @people_and_companies_bank_branch.save
          format.html { redirect_to @people_and_companies_bank_branch, :notice => 'Bank branch was successfully created.' }
          format.json { render :json => @people_and_companies_bank_branch, :status => :created, :location => @people_and_companies_bank_branch }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_branch.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_branches/1
    # PUT /people_and_companies/bank_branches/1.json
    def update
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_branch.update(params[:people_and_companies_bank_branch])
          format.html { redirect_to @people_and_companies_bank_branch, :notice => 'Bank branch was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_branch.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_branches/1
    # DELETE /people_and_companies/bank_branches/1.json
    def destroy
      @people_and_companies_bank_branch = PeopleAndCompanies::BankBranch.find(params[:id])
      @people_and_companies_bank_branch.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_branches_url }
        format.json { head :no_content }
      end
    end
  end
end
